@@ -367,6 +367,8 @@ sub _searchLdap
         }
     }
 
+    $filter =~ s/^["']//;
+    $filter =~ s/["']$//;
     if ($filter =~ /^\(?dn=/) {
         ($base) = ($filter =~ /^\(?dn=(.*)\)?$/);
         $scope = 'base';
