@@ -547,7 +547,10 @@ sub hashPasswd
     my $conf = $self->{_config};
 
     my $hashpw;
-    my ($htype, $otype) = split(/:/, $conf->{hash});
+    my ($htype, $otype, $num) = split(/:/, $conf->{hash});
+    if (!$num) {
+        $num = 1;
+    }
 
     my ($pwhtype) = ($passwd =~ /^\{([^\}]+)\}/);
     if ($pwhtype) {
@@ -565,30 +568,33 @@ sub hashPasswd
     }
 
     # hash the password
-    if ($htype =~ /^CRYPT$/i) {
-        my @chars = ('a'..'z', 'A'..'Z', '0'..'9');
-        if (!$salt) {
-            $salt .= $chars[int(rand($#chars + 1))] for (1..10);
-        }
-        $hashpw = crypt($passwd, $salt);
-    } elsif ($htype =~ /^MD5$/i) {
-        my $ctx = Digest::MD5->new;
-        $ctx->add($passwd);
-        if ($otype && $otype =~ /^hex$/i) {
-            $hashpw = $ctx->hexdigest;
+    for (my $i = 0; $i < $num; $i++) {
+        if ($htype =~ /^CRYPT$/i) {
+            my @chars = ('a'..'z', 'A'..'Z', '0'..'9');
+            if (!$salt) {
+                $salt .= $chars[int(rand($#chars + 1))] for (1..10);
+            }
+            $hashpw = crypt($passwd, $salt);
+        } elsif ($htype =~ /^MD5$/i) {
+            my $ctx = Digest::MD5->new;
+            $ctx->add($passwd);
+            if ($otype && $otype =~ /^hex$/i) {
+                $hashpw = $ctx->hexdigest;
+            } else {
+                $hashpw = $ctx->b64digest.'==';
+            }
+        } elsif ($htype =~ /^SHA$/i) {
+            my $ctx = Digest::SHA1->new;
+            $ctx->add($passwd);
+            if ($otype && $otype =~ /^hex$/i) {
+                $hashpw = $ctx->hexdigest;
+            } else {
+                $hashpw = $ctx->b64digest.'=';
+            }
         } else {
-            $hashpw = $ctx->b64digest.'==';
+            $hashpw = $passwd;
         }
-    } elsif ($htype =~ /^SHA$/i) {
-        my $ctx = Digest::SHA1->new;
-        $ctx->add($passwd);
-        if ($otype && $otype =~ /^hex$/i) {
-            $hashpw = $ctx->hexdigest;
-        } else {
-            $hashpw = $ctx->b64digest.'=';
-        }
-    } else {
-        $hashpw = $passwd;
+        $passwd = $hashpw;
     }
 
     return $hashpw;
@@ -1361,6 +1367,21 @@ sub _doPlugin
     }
 }
 
+sub _doFunction
+{
+    my $self = shift;
+    my ($function) = @_;
+    my $value;
+
+    eval "\$value = $function";
+    if ($@) {
+        $self->log(level => 'err', message => "Function $function failed: $@");
+        return $value;
+    }
+
+    return $value;
+}
+
 sub _pwdFormat
 {
     my $self = shift;
