@@ -169,7 +169,7 @@ sub _objSearch
             }
 
             # entries below suffix
-            if ($pkey && defined($oconf->{container}) && !defined($oconf->{container}[0]->{rdn})) {
+            if (defined($pkey) && defined($oconf->{container}) && !defined($oconf->{container}[0]->{rdn})) {
                 my $cur_pkey = $data[$oconf->{container}[0]->{idcolumn}[0]];
 
                 if (!($pkey =~ /^$cur_pkey$/i)) {
@@ -207,7 +207,7 @@ sub _objSearch
             $entry = "dn: $rdn,$suffix\n$entry";
 
             # parse filter
-            if ($self->parseFilter($filter, encode('utf8', $entry))) {
+            if ($self->parseFilter($filter, $entry)) {
                 push(@match_entries, $self->_pwdFormat($entry));
                 push(@match_keys, $data[$oconf->{id}[0]->{column}[0]]);
             }
@@ -290,7 +290,7 @@ sub _objModify
             }
 
             # entries below suffix
-            if ($pkey && defined($oconf->{container}) && !defined($oconf->{container}[0]->{rdn})) {
+            if (defined($pkey) && defined($oconf->{container}) && !defined($oconf->{container}[0]->{rdn})) {
                 my $cur_pkey = $data[$oconf->{container}[0]->{idcolumn}[0]];
 
                 if (!($pkey =~ /^$cur_pkey$/i)) {
@@ -479,7 +479,7 @@ sub _objAdd
         }
 
         # entries below suffix
-        if ($pkey && defined($oconf->{container}) && !defined($oconf->{container}[0]->{rdn})) {
+        if (defined($pkey) && defined($oconf->{container}) && !defined($oconf->{container}[0]->{rdn})) {
             my $cur_pkey = $data[$oconf->{container}[0]->{idcolumn}[0]];
             if ($pkey !~ /^$cur_pkey$/i) {
                 next;
@@ -621,7 +621,7 @@ sub _objDelete
         }
 
         # entries below suffix
-        if ($pkey && defined($oconf->{container}) && !defined($oconf->{container}[0]->{rdn})) {
+        if (defined($pkey) && defined($oconf->{container}) && !defined($oconf->{container}[0]->{rdn})) {
             my $cur_pkey = $data[$oconf->{container}[0]->{idcolumn}[0]];
 
             if (!($pkey =~ /^$cur_pkey$/i)) {
